#  Libreria Ecuaciones

Esta es una libreria para resolver sistemas de ecuaciones lineales y no lineales

## Metodos incluidos

### Lineales:
- Gauss
- Gauss-Jordan
- Cramer
- LU
- Jacobi
- Gauss-Seidel

### No lineales:
- Biseccion

## Instalación

```bash
pip install SG21038UNO
